@@ -6,11 +6,11 @@ load_dotenv()
 
 metal_api_key = os.environ["METAL_API_KEY"]
 metal_client_id = os.environ["METAL_CLIENT_ID"]
-metal_app_id = os.environ["METAL_APP_ID"]
+metal_index_id = os.environ["METAL_INDEX_ID"]
 
 
 def main():
-    metal = Metal(metal_api_key, metal_client_id, metal_app_id)
+    metal = Metal(metal_api_key, metal_client_id, metal_index_id)
 
     # metal.index({ "id": "667", "text": "Dave Mustain" })
     # metal.index({ "id": "666", "text": "Ozzy" })
